def load_data(filename):
    """Carica dati da un file tabellare. Restituisce un dizionario, 
con il nome della colonna come chiave e il resto della colonna come 
valore."""
    f = open(filename)
    diz = {}

    # extract keys
    keys = f.readline().split()

    # extract values
    values = [[] for i in range(len(keys))]
    for row in f:
        data = row.split()
        for i in range(len(data)):
            values[i].append(data[i])

    # build dictionary
    for k,v in zip(keys, values):
        diz[k] = v

    f.close()
    return diz

def extract_groups(group, attribute):
    """Prende in ingresso due liste. Restituisce un dizionario con 
i valori della prima lista come chiave, e gli elementi della seconda 
lista con quel valore come valore."""
    diz = {}
    for k,v in zip(group, attribute):
        if not k in diz:
            diz[k] = [v]
        else:
            diz[k].append(v)
    return diz

def print_stats(attribute_by_group, is_continuous):
    """Stampa le statistiche sui valori degli attributi per ogni gruppo"""
    for k,v in attribute_by_group.items():
        buf = k + "\t"
        if is_continuous:
            stats = compute_mean(v)
            buf += "%.1f" %stats
        else:
            stats = compute_histogram(v)
            # WARNING: k,v inside list comprehension work because of local scope 
            # but not good practice
            buf += " ".join(["%s->%d" %(k,v) for k,v in stats.items()])
        print(buf)

def compute_mean(values):
    """Restituisce la media di una lista di valori."""
    mean = 0
    for val in values:
        mean += float(val)
    return mean/len(values)

def compute_histogram(values):
    """Restituisce il dizionario di frequenze dei valori contenuti in una lista.""" 
    histo = {}
    for val in values:
        if not val in histo:
            histo[val] = 1
        else:
            histo[val] += 1
    return histo

filename = input("Inserire nome file: ")
group = input("Inserire classificazione: ")
attribute = input("Inserire attributo: ")
is_continuous = input("Attributo continuo?[S/N]: ").upper()

while(is_continuous != 'S' and is_continuous != 'N'):
    is_continuous = input("Si prega rispondere con S o N: ").upper()

if is_continuous == 'S':
    is_continuous = True
else:
    is_continuous = False

data = load_data(filename)
groups = extract_groups(data[group], data[attribute])
print(group + "\t" + attribute)
print_stats(groups, is_continuous)
